==> react-native-yamap2-4.1.1-8.2.tgz: package/ios/View/RNCYMView.h <==
#ifndef RNCYMView_h
#define RNCYMView_h
#import <React/RCTComponent.h>

#import <MapKit/MapKit.h>
#import <RNYMView.h>
@import YandexMapsMobile;

@class RCTBridge;

@interface RNCYMView: RNYMView<YMKClusterListener, YMKClusterTapListener>

@property (nonatomic, assign) CGRect mapFrame;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onCameraPositionReceived;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onVisibleRegionReceived;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onCameraPositionChange;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onCameraPositionChangeEnd;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onMapPress;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onMapLongPress;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onMapLoaded;

- (void)setClusterColor:(UIColor*_Nullable)color;
- (void)setClusteredMarkers:(NSArray<YMKRequestPoint*>*_Nonnull)points;

// REF
- (void)emitCameraPositionToJS:(NSString *_Nonnull)_id;
- (void)emitVisibleRegionToJS:(NSString *_Nonnull)_id;
- (void)setCenter:(YMKCameraPosition *_Nonnull)position withDuration:(float)duration withAnimation:(int)animation;
- (void)setZoom:(float)zoom withDuration:(float)duration withAnimation:(int)animation;
- (void)fitAllMarkers;
- (void)fitMarkers:(NSArray<YMKPoint *> *_Nonnull)points;

// PROPS
- (void)setNightMode:(BOOL)nightMode;
- (void)setListenUserLocation:(BOOL)listen;
- (void)setUserLocationIcon:(NSString *_Nullable)iconSource;
- (void)setMapType:(NSString *_Nullable)type;
- (void)setInitialRegion:(NSDictionary *_Nullable)initialRegion;
- (void)setMaxFps:(float)maxFps;
- (void)setInteractive:(BOOL)interactive;
- (void)insertMarkerReactSubview:(UIView *_Nullable)subview atIndex:(NSInteger)atIndex;
- (void)removeMarkerReactSubview:(UIView *_Nullable)subview;
- (void)setFollowUser:(BOOL)follow;
- (void)setLogoPosition:(NSDictionary *_Nullable)logoPosition;
- (void)setLogoPadding:(NSDictionary *_Nullable)logoPadding;

@end

#endif /* RNYMView_h */

==> react-native-yamap2-4.1.1-9.tgz: package/ios/View/RNCYMView.h <==
#ifndef RNCYMView_h
#define RNCYMView_h
#import <React/RCTComponent.h>

#import <MapKit/MapKit.h>
#import <RNYMView.h>
@import YandexMapsMobile;

@class RCTBridge;

@interface RNCYMView: RNYMView<YMKUserLocationObjectListener,RCTComponent,YMKMapCameraListener,YMKMapLoadedListener,YMKClusterListener, YMKClusterTapListener>

@property (nonatomic, assign) CGRect mapFrame;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onCameraPositionReceived;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onVisibleRegionReceived;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onCameraPositionChange;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onCameraPositionChangeEnd;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onMapPress;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onMapLongPress;
@property (nonatomic, copy) RCTBubblingEventBlock _Nullable onMapLoaded;
@property (nonatomic, copy) NSDictionary *initialRegion;

- (void)setClusterColor:(UIColor*_Nullable)color;
- (void)setClusteredMarkers:(NSArray<YMKRequestPoint*>*_Nonnull)points;

// REF
- (void)emitCameraPositionToJS:(NSString *_Nonnull)_id;
- (void)emitVisibleRegionToJS:(NSString *_Nonnull)_id;
- (void)setCenter:(YMKCameraPosition *_Nonnull)position withDuration:(float)duration withAnimation:(int)animation;
- (void)setZoom:(float)zoom withDuration:(float)duration withAnimation:(int)animation;
- (void)fitAllMarkers;
- (void)fitMarkers:(NSArray<YMKPoint *> *_Nonnull)points;

// PROPS
- (void)setNightMode:(BOOL)nightMode;
- (void)setListenUserLocation:(BOOL)listen;
- (void)setUserLocationIcon:(NSString *_Nullable)iconSource;
- (void)setMapType:(NSString *_Nullable)type;
- (void)setInitialRegion:(NSDictionary *_Nullable)initialRegion;
- (void)setMaxFps:(float)maxFps;
- (void)setInteractive:(BOOL)interactive;
- (void)insertMarkerReactSubview:(UIView *_Nullable)subview atIndex:(NSInteger)atIndex;
- (void)removeMarkerReactSubview:(UIView *_Nullable)subview;
- (void)setFollowUser:(BOOL)follow;
- (void)setLogoPosition:(NSDictionary *_Nullable)logoPosition;
- (void)setLogoPadding:(NSDictionary *_Nullable)logoPadding;

@end

#endif /* RNYMView_h */
